#!/bin/bash


HORIZON_CONFIG=${HORIZON_CONFIG:-'/usr/share/openstack-dashboard/openstack_dashboard/settings.py'}

MURANO_AUTH_HOST=${MURANO_AUTH_HOST:-'localhost'}

MURANO_SSL_ENABLED=${MURANO_SSL_ENABLED:-'False'}

MURANO_API_PROTOCOL=${MURANO_API_PROTOCOL:-'http'}
MURANO_API_HOST=${MURANO_API_HOST:-'localhost'}
MURANO_API_PORT=${MURANO_API_PORT:-'8082'}

MURANO_METADATA_PROTOCOL=${MURANO_METADATA_PROTOCOL:-'http'}
MURANO_METADATA_HOST=${MURANO_METADATA_HOST:-'localhost'}
MURANO_METADATA_PORT=${MURANO_METADATA_PORT:-'8084'}

MURANO_DASHBOARD_CACHE=${MURANO_DASHBOARD_CACHE:-'/var/cache/muranodashboard-cache'}

MURANO_LOG_DIR=${MURANO_LOG_DIR:-'/var/log/murano'}

MURANO_DASHBOARD_DB_DIR=${MURANO_DASHBOARD_DB_DIR:-'/var/lib/openstack-dashboard'}


# /Functions/ ==================================================================

# Normalize config values to True or False
# Accepts as False: 0 no No NO false False FALSE
# Accepts as True: 1 yes Yes YES true True TRUE
# VAR=$(trueorfalse default-value test-value)
function trueorfalse() {
    local default=$1
    local testval=$2

    [[ -z "$testval" ]] && { echo "$default"; return; }
    [[ "0 no No NO false False FALSE" =~ "$testval" ]] && { echo "False"; return; }
    [[ "1 yes Yes YES true True TRUE" =~ "$testval" ]] && { echo "True"; return; }
    echo "$default"
}


# Insert content of one file into another before a string which mathes pattern
function insert_before_pattern() {
    local pattern="$1"
    local insert_file="$2"
    local target_file="$3"

    sed -ne "/$pattern/r  $insert_file" -e 1x  -e '2,${x;p}' -e '${x;p}' -i $target_file
}


# Remove Murano-related parts of configuration (code between special tags)
function restore_horizon_config() {
    local config_file="$1"

    if [[ -f "$config_file" ]]; then
        sed -e '/^#MURANO_CONFIG_SECTION_BEGIN/,/^#MURANO_CONFIG_SECTION_END/ d' -i "$config_file"
    fi
}


# Insert Murano-related configuration into several Horizon config files
function configure_murano_dashboard() {
    local horizon_config_part=$(mktemp)

    # Opening Murano Configuration Section
    cat << EOF >> "$horizon_config_part"

#MURANO_CONFIG_SECTION_BEGIN
#-------------------------------------------------------------------------------

EOF


    if [[ $(trueorfalse False $MURANO_SSL_ENABLED) = 'True' ]]; then
        cat << EOF >> "$horizon_config_part"
MURANO_API_INSECURE = $MURANO_API_INSECURE
EOF
    fi


    cat << EOF >> "$horizon_config_part"
MURANO_API_URL = "$MURANO_API_PROTOCOL://$MURANO_API_HOST:$MURANO_API_PORT"
MURANO_METADATA_URL = "$MURANO_METADATA_PROTOCOL://$MURANO_METADATA_HOST:$MURANO_METADATA_PORT/v1"

EOF


    cat << EOF >> "$horizon_config_part"
#TODO: should remove the next line once https://bugs.launchpad.net/ubuntu/+source/horizon/+bug/1243187 is fixed
#LOGOUT_URL = '/horizon/auth/logout/'
METADATA_CACHE_DIR = '$MURANO_DASHBOARD_CACHE'
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join('$MURANO_DASHBOARD_DB_DIR', 'openstack-dashboard.sqlite')
    }
}
SESSION_ENGINE = 'django.contrib.sessions.backends.db'
HORIZON_CONFIG['dashboards'] += ('murano',)
INSTALLED_APPS += ('muranodashboard','floppyforms',)
MIDDLEWARE_CLASSES += ('muranodashboard.middleware.ExceptionMiddleware',)

verbose_formatter = {'verbose': {'format': '[%(asctime)s] [%(levelname)s] [pid=%(process)d] %(message)s'}}
if 'formatters' in LOGGING: LOGGING['formatters'].update(verbose_formatter)
else: LOGGING['formatters'] = verbose_formatter

LOGGING['handlers']['murano-file'] = {'level': 'DEBUG', 'formatter': 'verbose', 'class': 'logging.FileHandler', 'filename': '$MURANO_LOG_DIR/murano-dashboard.log'}
LOGGING['loggers']['muranodashboard'] = {'handlers': ['murano-file'], 'level': 'DEBUG'}
LOGGING['loggers']['muranoclient'] = {'handlers': ['murano-file'], 'level': 'ERROR'}

#MURANO_API_URL = "http://localhost:8082"
#MURANO_METADATA_URL = "http://localhost:8084/v1"
#if murano-api set up with ssl uncomment next strings
#MURANO_API_INSECURE = True

ADVANCED_NETWORKING_CONFIG = {'max_environments': 100, 'max_hosts': 250, 'env_ip_template': '10.0.0.0'}
NETWORK_TOPOLOGY = 'routed'

EOF

    # Closing Murano Configuration Section
    cat << EOF >> "$horizon_config_part"
#-------------------------------------------------------------------------------
#MURANO_CONFIG_SECTION_END


EOF

    insert_before_pattern "from openstack_dashboard import policy" "$horizon_config_part" "$HORIZON_CONFIG"
}

# \Functions\ ==================================================================


# Script usage:
#   modify-horizon-config.sh <command>

case "$1" in
    install)
        configure_murano_dashboard
    ;;
    uninstall)
        restore_horizon_config "$HORIZON_CONFIG"
    ;;
    *)
        exit 1
    ;;
esac
